@@ -23,12 +23,14 @@ import org.apache.kyuubi.tags.DeltaTest
 
 @DeltaTest
 class SparkDeltaOperationSuite extends WithSparkSQLEngine with BasicDeltaJDBCTests {
+
   override protected def jdbcUrl: String = getJdbcUrl
+
   override def withKyuubiConf: Map[String, String] = extraConfigs
 
   override def afterAll(): Unit = {
     super.afterAll()
-    for ((k, _) <- extraConfigs) {
+    for ((k, _) <- withKyuubiConf) {
       System.clearProperty(k)
     }
   }
